defmodule Textos.Content.Media do
  use Ecto.Schema
  import Ecto.Changeset

  @primary_key {:id, :binary_id, autogenerate: true}
  @foreign_key_type :binary_id
  schema "media" do
    field :description, :string
    field :location, :string
    field :title, :string
    field :note, :string
    field :media_type, :string
    field :collected_by, :string
    field :old_filename, :string
    field :translated_esp, :boolean, default: false
    field :transcribed, :boolean, default: false
    field :speakers, {:array, :string}
    field :translated_eng, :boolean, default: false
    field :recorded_at, :utc_datetime
    field :record_dated, :boolean, default: false

    has_many :translations, Textos.Content.Translation
    has_many :transcriptions, Textos.Content.Transcription
    has_many :subtitles, Textos.Content.Subtitle

    timestamps()
  end

  @doc false
  def changeset(media, attrs) do
    media
    |> cast(attrs, [:title, :note, :media_type, :collected_by, :old_filename, :translated_esp, :transcribed, :speakers, :translated_eng, :recorded_at, :description, :location, :record_dated])
    |> validate_required([:title, :note, :media_type, :collected_by, :old_filename, :translated_esp, :speakers, :translated_eng, :recorded_at, :description, :location, :record_dated])
  end
end
