defmodule TextosWeb.MediaController do
  use TextosWeb, :controller

  alias Textos.Content
  alias Textos.Content.Media

  def index(conn, _params) do
    media = Content.list_media()
    render(conn, :index, media: media)
  end

  def new(conn, _params) do
    changeset = Content.change_media(%Media{})
    render(conn, :new, changeset: changeset)
  end

  def create(conn, %{"media" => media_params}) do
    case Content.create_media(media_params) do
      {:ok, media} ->
        conn
        |> put_flash(:info, "Media created successfully.")
        |> redirect(to: ~p"/media/#{media}")

      {:error, %Ecto.Changeset{} = changeset} ->
        render(conn, :new, changeset: changeset)
    end
  end

  def show(conn, %{"id" => id}) do
    media = Content.get_media!(id)
    render(conn, :show, media: media)
  end

  def edit(conn, %{"id" => id}) do
    media = Content.get_media!(id)
    changeset = Content.change_media(media)
    render(conn, :edit, media: media, changeset: changeset)
  end

  def update(conn, %{"id" => id, "media" => media_params}) do
    media = Content.get_media!(id)

    case Content.update_media(media, media_params) do
      {:ok, media} ->
        conn
        |> put_flash(:info, "Media updated successfully.")
        |> redirect(to: ~p"/media/#{media}")

      {:error, %Ecto.Changeset{} = changeset} ->
        render(conn, :edit, media: media, changeset: changeset)
    end
  end

  def delete(conn, %{"id" => id}) do
    media = Content.get_media!(id)
    {:ok, _media} = Content.delete_media(media)

    conn
    |> put_flash(:info, "Media deleted successfully.")
    |> redirect(to: ~p"/media")
  end
end
