defmodule TextosWeb.SubtitleController do
  use TextosWeb, :controller

  alias Textos.Content
  alias Textos.Content.Subtitle

  def index(conn, _params) do
    subtitles = Content.list_subtitles()
    render(conn, :index, subtitles: subtitles)
  end

  def new(conn, _params) do
    changeset = Content.change_subtitle(%Subtitle{})
    render(conn, :new, changeset: changeset)
  end

  def create(conn, %{"subtitle" => subtitle_params}) do
    case Content.create_subtitle(subtitle_params) do
      {:ok, subtitle} ->
        conn
        |> put_flash(:info, "Subtitle created successfully.")
        |> redirect(to: ~p"/subtitles/#{subtitle}")

      {:error, %Ecto.Changeset{} = changeset} ->
        render(conn, :new, changeset: changeset)
    end
  end

  def show(conn, %{"id" => id}) do
    subtitle = Content.get_subtitle!(id)
    render(conn, :show, subtitle: subtitle)
  end

  def edit(conn, %{"id" => id}) do
    subtitle = Content.get_subtitle!(id)
    changeset = Content.change_subtitle(subtitle)
    render(conn, :edit, subtitle: subtitle, changeset: changeset)
  end

  def update(conn, %{"id" => id, "subtitle" => subtitle_params}) do
    subtitle = Content.get_subtitle!(id)

    case Content.update_subtitle(subtitle, subtitle_params) do
      {:ok, subtitle} ->
        conn
        |> put_flash(:info, "Subtitle updated successfully.")
        |> redirect(to: ~p"/subtitles/#{subtitle}")

      {:error, %Ecto.Changeset{} = changeset} ->
        render(conn, :edit, subtitle: subtitle, changeset: changeset)
    end
  end

  def delete(conn, %{"id" => id}) do
    subtitle = Content.get_subtitle!(id)
    {:ok, _subtitle} = Content.delete_subtitle(subtitle)

    conn
    |> put_flash(:info, "Subtitle deleted successfully.")
    |> redirect(to: ~p"/subtitles")
  end
end
