defmodule TextosWeb.TranscriptionController do
  use TextosWeb, :controller

  alias Textos.Content
  alias Textos.Content.Transcription

  def index(conn, _params) do
    transcriptions = Content.list_transcriptions()
    render(conn, :index, transcriptions: transcriptions)
  end

  def new(conn, _params) do
    changeset = Content.change_transcription(%Transcription{})
    render(conn, :new, changeset: changeset)
  end

  def create(conn, %{"transcription" => transcription_params}) do
    case Content.create_transcription(transcription_params) do
      {:ok, transcription} ->
        conn
        |> put_flash(:info, "Transcription created successfully.")
        |> redirect(to: ~p"/transcriptions/#{transcription}")

      {:error, %Ecto.Changeset{} = changeset} ->
        render(conn, :new, changeset: changeset)
    end
  end

  def show(conn, %{"id" => id}) do
    transcription = Content.get_transcription!(id)
    render(conn, :show, transcription: transcription)
  end

  def edit(conn, %{"id" => id}) do
    transcription = Content.get_transcription!(id)
    changeset = Content.change_transcription(transcription)
    render(conn, :edit, transcription: transcription, changeset: changeset)
  end

  def update(conn, %{"id" => id, "transcription" => transcription_params}) do
    transcription = Content.get_transcription!(id)

    case Content.update_transcription(transcription, transcription_params) do
      {:ok, transcription} ->
        conn
        |> put_flash(:info, "Transcription updated successfully.")
        |> redirect(to: ~p"/transcriptions/#{transcription}")

      {:error, %Ecto.Changeset{} = changeset} ->
        render(conn, :edit, transcription: transcription, changeset: changeset)
    end
  end

  def delete(conn, %{"id" => id}) do
    transcription = Content.get_transcription!(id)
    {:ok, _transcription} = Content.delete_transcription(transcription)

    conn
    |> put_flash(:info, "Transcription deleted successfully.")
    |> redirect(to: ~p"/transcriptions")
  end
end
