defmodule TextosWeb.TranslationController do
  use TextosWeb, :controller

  alias Textos.Content
  alias Textos.Content.Translation

  def index(conn, _params) do
    translations = Content.list_translations()
    render(conn, :index, translations: translations)
  end

  def new(conn, _params) do
    changeset = Content.change_translation(%Translation{})
    render(conn, :new, changeset: changeset)
  end

  def create(conn, %{"translation" => translation_params}) do
    case Content.create_translation(translation_params) do
      {:ok, translation} ->
        conn
        |> put_flash(:info, "Translation created successfully.")
        |> redirect(to: ~p"/translations/#{translation}")

      {:error, %Ecto.Changeset{} = changeset} ->
        render(conn, :new, changeset: changeset)
    end
  end

  def show(conn, %{"id" => id}) do
    translation = Content.get_translation!(id)
    render(conn, :show, translation: translation)
  end

  def edit(conn, %{"id" => id}) do
    translation = Content.get_translation!(id)
    changeset = Content.change_translation(translation)
    render(conn, :edit, translation: translation, changeset: changeset)
  end

  def update(conn, %{"id" => id, "translation" => translation_params}) do
    translation = Content.get_translation!(id)

    case Content.update_translation(translation, translation_params) do
      {:ok, translation} ->
        conn
        |> put_flash(:info, "Translation updated successfully.")
        |> redirect(to: ~p"/translations/#{translation}")

      {:error, %Ecto.Changeset{} = changeset} ->
        render(conn, :edit, translation: translation, changeset: changeset)
    end
  end

  def delete(conn, %{"id" => id}) do
    translation = Content.get_translation!(id)
    {:ok, _translation} = Content.delete_translation(translation)

    conn
    |> put_flash(:info, "Translation deleted successfully.")
    |> redirect(to: ~p"/translations")
  end
end
