defmodule Textos.ContentFixtures do
  @moduledoc """
  This module defines test helpers for creating
  entities via the `Textos.Content` context.
  """

  @doc """
  Generate a media.
  """
  def media_fixture(attrs \\ %{}) do
    {:ok, media} =
      attrs
      |> Enum.into(%{
        description: "some description",
        location: "some location",
        title: "some title",
        note: "some note",
        media_type: "some media_type",
        collected_by: "some collected_by",
        old_filename: "some old_filename",
        translated_esp: true,
        speakers: ["option1", "option2"],
        translated_eng: true,
        recorded_at: ~U[2023-07-28 01:42:00Z],
        record_dated: true
      })
      |> Textos.Content.create_media()

    media
  end

  @doc """
  Generate a subtitle.
  """
  def subtitle_fixture(attrs \\ %{}) do
    {:ok, subtitle} =
      attrs
      |> Enum.into(%{
        complete: true,
        format: "some format",
        language: "some language",
        note: "some note",
        final_draft: true,
        subtitle_text: "some subtitle_text",
        subtitler: "some subtitler",
        editors: ["option1", "option2"]
      })
      |> Textos.Content.create_subtitle()

    subtitle
  end

  @doc """
  Generate a transcription.
  """
  def transcription_fixture(attrs \\ %{}) do
    {:ok, transcription} =
      attrs
      |> Enum.into(%{
        complete: true,
        note: "some note",
        final_draft: true,
        transcription_text: "some transcription_text",
        transcriber: "some transcriber",
        editors: ["option1", "option2"]
      })
      |> Textos.Content.create_transcription()

    transcription
  end

  @doc """
  Generate a translation.
  """
  def translation_fixture(attrs \\ %{}) do
    {:ok, translation} =
      attrs
      |> Enum.into(%{
        complete: true,
        translator: "some translator",
        language: "some language",
        note: "some note",
        final_draft: true,
        translation_text: "some translation_text",
        editors: ["option1", "option2"]
      })
      |> Textos.Content.create_translation()

    translation
  end
end
