defmodule TextosWeb.MediaControllerTest do
  use TextosWeb.ConnCase

  import Textos.ContentFixtures

  @create_attrs %{description: "some description", location: "some location", title: "some title", note: "some note", media_type: "some media_type", collected_by: "some collected_by", old_filename: "some old_filename", translated_esp: true, speakers: ["option1", "option2"], translated_eng: true, recorded_at: ~U[2023-07-28 01:42:00Z], record_dated: true}
  @update_attrs %{description: "some updated description", location: "some updated location", title: "some updated title", note: "some updated note", media_type: "some updated media_type", collected_by: "some updated collected_by", old_filename: "some updated old_filename", translated_esp: false, speakers: ["option1"], translated_eng: false, recorded_at: ~U[2023-07-29 01:42:00Z], record_dated: false}
  @invalid_attrs %{description: nil, location: nil, title: nil, note: nil, media_type: nil, collected_by: nil, old_filename: nil, translated_esp: nil, speakers: nil, translated_eng: nil, recorded_at: nil, record_dated: nil}

  describe "index" do
    test "lists all media", %{conn: conn} do
      conn = get(conn, ~p"/media")
      assert html_response(conn, 200) =~ "Listing Media"
    end
  end

  describe "new media" do
    test "renders form", %{conn: conn} do
      conn = get(conn, ~p"/media/new")
      assert html_response(conn, 200) =~ "New Media"
    end
  end

  describe "create media" do
    test "redirects to show when data is valid", %{conn: conn} do
      conn = post(conn, ~p"/media", media: @create_attrs)

      assert %{id: id} = redirected_params(conn)
      assert redirected_to(conn) == ~p"/media/#{id}"

      conn = get(conn, ~p"/media/#{id}")
      assert html_response(conn, 200) =~ "Media #{id}"
    end

    test "renders errors when data is invalid", %{conn: conn} do
      conn = post(conn, ~p"/media", media: @invalid_attrs)
      assert html_response(conn, 200) =~ "New Media"
    end
  end

  describe "edit media" do
    setup [:create_media]

    test "renders form for editing chosen media", %{conn: conn, media: media} do
      conn = get(conn, ~p"/media/#{media}/edit")
      assert html_response(conn, 200) =~ "Edit Media"
    end
  end

  describe "update media" do
    setup [:create_media]

    test "redirects when data is valid", %{conn: conn, media: media} do
      conn = put(conn, ~p"/media/#{media}", media: @update_attrs)
      assert redirected_to(conn) == ~p"/media/#{media}"

      conn = get(conn, ~p"/media/#{media}")
      assert html_response(conn, 200) =~ "some updated description"
    end

    test "renders errors when data is invalid", %{conn: conn, media: media} do
      conn = put(conn, ~p"/media/#{media}", media: @invalid_attrs)
      assert html_response(conn, 200) =~ "Edit Media"
    end
  end

  describe "delete media" do
    setup [:create_media]

    test "deletes chosen media", %{conn: conn, media: media} do
      conn = delete(conn, ~p"/media/#{media}")
      assert redirected_to(conn) == ~p"/media"

      assert_error_sent 404, fn ->
        get(conn, ~p"/media/#{media}")
      end
    end
  end

  defp create_media(_) do
    media = media_fixture()
    %{media: media}
  end
end
