defmodule TextosWeb.SubtitleControllerTest do
  use TextosWeb.ConnCase

  import Textos.ContentFixtures

  @create_attrs %{complete: true, format: "some format", language: "some language", note: "some note", final_draft: true, subtitle_text: "some subtitle_text", subtitler: "some subtitler", editors: ["option1", "option2"]}
  @update_attrs %{complete: false, format: "some updated format", language: "some updated language", note: "some updated note", final_draft: false, subtitle_text: "some updated subtitle_text", subtitler: "some updated subtitler", editors: ["option1"]}
  @invalid_attrs %{complete: nil, format: nil, language: nil, note: nil, final_draft: nil, subtitle_text: nil, subtitler: nil, editors: nil}

  describe "index" do
    test "lists all subtitles", %{conn: conn} do
      conn = get(conn, ~p"/subtitles")
      assert html_response(conn, 200) =~ "Listing Subtitles"
    end
  end

  describe "new subtitle" do
    test "renders form", %{conn: conn} do
      conn = get(conn, ~p"/subtitles/new")
      assert html_response(conn, 200) =~ "New Subtitle"
    end
  end

  describe "create subtitle" do
    test "redirects to show when data is valid", %{conn: conn} do
      conn = post(conn, ~p"/subtitles", subtitle: @create_attrs)

      assert %{id: id} = redirected_params(conn)
      assert redirected_to(conn) == ~p"/subtitles/#{id}"

      conn = get(conn, ~p"/subtitles/#{id}")
      assert html_response(conn, 200) =~ "Subtitle #{id}"
    end

    test "renders errors when data is invalid", %{conn: conn} do
      conn = post(conn, ~p"/subtitles", subtitle: @invalid_attrs)
      assert html_response(conn, 200) =~ "New Subtitle"
    end
  end

  describe "edit subtitle" do
    setup [:create_subtitle]

    test "renders form for editing chosen subtitle", %{conn: conn, subtitle: subtitle} do
      conn = get(conn, ~p"/subtitles/#{subtitle}/edit")
      assert html_response(conn, 200) =~ "Edit Subtitle"
    end
  end

  describe "update subtitle" do
    setup [:create_subtitle]

    test "redirects when data is valid", %{conn: conn, subtitle: subtitle} do
      conn = put(conn, ~p"/subtitles/#{subtitle}", subtitle: @update_attrs)
      assert redirected_to(conn) == ~p"/subtitles/#{subtitle}"

      conn = get(conn, ~p"/subtitles/#{subtitle}")
      assert html_response(conn, 200) =~ "some updated format"
    end

    test "renders errors when data is invalid", %{conn: conn, subtitle: subtitle} do
      conn = put(conn, ~p"/subtitles/#{subtitle}", subtitle: @invalid_attrs)
      assert html_response(conn, 200) =~ "Edit Subtitle"
    end
  end

  describe "delete subtitle" do
    setup [:create_subtitle]

    test "deletes chosen subtitle", %{conn: conn, subtitle: subtitle} do
      conn = delete(conn, ~p"/subtitles/#{subtitle}")
      assert redirected_to(conn) == ~p"/subtitles"

      assert_error_sent 404, fn ->
        get(conn, ~p"/subtitles/#{subtitle}")
      end
    end
  end

  defp create_subtitle(_) do
    subtitle = subtitle_fixture()
    %{subtitle: subtitle}
  end
end
