defmodule TextosWeb.TranscriptionControllerTest do
  use TextosWeb.ConnCase

  import Textos.ContentFixtures

  @create_attrs %{complete: true, note: "some note", final_draft: true, transcription_text: "some transcription_text", transcriber: "some transcriber", editors: ["option1", "option2"]}
  @update_attrs %{complete: false, note: "some updated note", final_draft: false, transcription_text: "some updated transcription_text", transcriber: "some updated transcriber", editors: ["option1"]}
  @invalid_attrs %{complete: nil, note: nil, final_draft: nil, transcription_text: nil, transcriber: nil, editors: nil}

  describe "index" do
    test "lists all transcriptions", %{conn: conn} do
      conn = get(conn, ~p"/transcriptions")
      assert html_response(conn, 200) =~ "Listing Transcriptions"
    end
  end

  describe "new transcription" do
    test "renders form", %{conn: conn} do
      conn = get(conn, ~p"/transcriptions/new")
      assert html_response(conn, 200) =~ "New Transcription"
    end
  end

  describe "create transcription" do
    test "redirects to show when data is valid", %{conn: conn} do
      conn = post(conn, ~p"/transcriptions", transcription: @create_attrs)

      assert %{id: id} = redirected_params(conn)
      assert redirected_to(conn) == ~p"/transcriptions/#{id}"

      conn = get(conn, ~p"/transcriptions/#{id}")
      assert html_response(conn, 200) =~ "Transcription #{id}"
    end

    test "renders errors when data is invalid", %{conn: conn} do
      conn = post(conn, ~p"/transcriptions", transcription: @invalid_attrs)
      assert html_response(conn, 200) =~ "New Transcription"
    end
  end

  describe "edit transcription" do
    setup [:create_transcription]

    test "renders form for editing chosen transcription", %{conn: conn, transcription: transcription} do
      conn = get(conn, ~p"/transcriptions/#{transcription}/edit")
      assert html_response(conn, 200) =~ "Edit Transcription"
    end
  end

  describe "update transcription" do
    setup [:create_transcription]

    test "redirects when data is valid", %{conn: conn, transcription: transcription} do
      conn = put(conn, ~p"/transcriptions/#{transcription}", transcription: @update_attrs)
      assert redirected_to(conn) == ~p"/transcriptions/#{transcription}"

      conn = get(conn, ~p"/transcriptions/#{transcription}")
      assert html_response(conn, 200) =~ "some updated note"
    end

    test "renders errors when data is invalid", %{conn: conn, transcription: transcription} do
      conn = put(conn, ~p"/transcriptions/#{transcription}", transcription: @invalid_attrs)
      assert html_response(conn, 200) =~ "Edit Transcription"
    end
  end

  describe "delete transcription" do
    setup [:create_transcription]

    test "deletes chosen transcription", %{conn: conn, transcription: transcription} do
      conn = delete(conn, ~p"/transcriptions/#{transcription}")
      assert redirected_to(conn) == ~p"/transcriptions"

      assert_error_sent 404, fn ->
        get(conn, ~p"/transcriptions/#{transcription}")
      end
    end
  end

  defp create_transcription(_) do
    transcription = transcription_fixture()
    %{transcription: transcription}
  end
end
