defmodule TextosWeb.TranslationControllerTest do
  use TextosWeb.ConnCase

  import Textos.ContentFixtures

  @create_attrs %{complete: true, translator: "some translator", language: "some language", note: "some note", final_draft: true, translation_text: "some translation_text", editors: ["option1", "option2"]}
  @update_attrs %{complete: false, translator: "some updated translator", language: "some updated language", note: "some updated note", final_draft: false, translation_text: "some updated translation_text", editors: ["option1"]}
  @invalid_attrs %{complete: nil, translator: nil, language: nil, note: nil, final_draft: nil, translation_text: nil, editors: nil}

  describe "index" do
    test "lists all translations", %{conn: conn} do
      conn = get(conn, ~p"/translations")
      assert html_response(conn, 200) =~ "Listing Translations"
    end
  end

  describe "new translation" do
    test "renders form", %{conn: conn} do
      conn = get(conn, ~p"/translations/new")
      assert html_response(conn, 200) =~ "New Translation"
    end
  end

  describe "create translation" do
    test "redirects to show when data is valid", %{conn: conn} do
      conn = post(conn, ~p"/translations", translation: @create_attrs)

      assert %{id: id} = redirected_params(conn)
      assert redirected_to(conn) == ~p"/translations/#{id}"

      conn = get(conn, ~p"/translations/#{id}")
      assert html_response(conn, 200) =~ "Translation #{id}"
    end

    test "renders errors when data is invalid", %{conn: conn} do
      conn = post(conn, ~p"/translations", translation: @invalid_attrs)
      assert html_response(conn, 200) =~ "New Translation"
    end
  end

  describe "edit translation" do
    setup [:create_translation]

    test "renders form for editing chosen translation", %{conn: conn, translation: translation} do
      conn = get(conn, ~p"/translations/#{translation}/edit")
      assert html_response(conn, 200) =~ "Edit Translation"
    end
  end

  describe "update translation" do
    setup [:create_translation]

    test "redirects when data is valid", %{conn: conn, translation: translation} do
      conn = put(conn, ~p"/translations/#{translation}", translation: @update_attrs)
      assert redirected_to(conn) == ~p"/translations/#{translation}"

      conn = get(conn, ~p"/translations/#{translation}")
      assert html_response(conn, 200) =~ "some updated translator"
    end

    test "renders errors when data is invalid", %{conn: conn, translation: translation} do
      conn = put(conn, ~p"/translations/#{translation}", translation: @invalid_attrs)
      assert html_response(conn, 200) =~ "Edit Translation"
    end
  end

  describe "delete translation" do
    setup [:create_translation]

    test "deletes chosen translation", %{conn: conn, translation: translation} do
      conn = delete(conn, ~p"/translations/#{translation}")
      assert redirected_to(conn) == ~p"/translations"

      assert_error_sent 404, fn ->
        get(conn, ~p"/translations/#{translation}")
      end
    end
  end

  defp create_translation(_) do
    translation = translation_fixture()
    %{translation: translation}
  end
end
